kedro.extras.datasets.spark.SparkHiveDataSet — Kedro 0.17.6 documentation

# kedro.extras.datasets.spark.SparkHiveDataSet

class `kedro.extras.datasets.spark.` `SparkHiveDataSet`(database, table, write_mode, table_pk=None)

  `SparkHiveDataSet` loads and saves Spark dataframes stored on Hive. This data set also handles some incompatible file types such as using partitioned parquet on hive which will not normally allow upserts to existing data without a complete replacement of the existing file/partition.

  This DataSet has some key assumptions: - Schemas do not change during the pipeline run (defined PKs must be present for the duration of the pipeline) - Tables are not being externally modified during upserts. The upsert method is NOT ATOMIC to external changes to the target table while executing.

  Example adding a catalog entry with YAML API:

      hive_dataset:
        type: spark.SparkHiveDataSet
        database: hive_database
        table: table_name
        write_mode: overwrite

  Example using Python API:

      from pyspark.sql import SparkSession
      from pyspark.sql.types import (StructField, StringType,
                                     IntegerType, StructType)

      from kedro.extras.datasets.spark import SparkHiveDataSet

      schema = StructType([StructField("name", StringType(), True),
                           StructField("age", IntegerType(), True)])

      data = [('Alex', 31), ('Bob', 12), ('Clarke', 65), ('Dave', 29)]

      spark_df = SparkSession.builder.getOrCreate().createDataFrame(data, schema)

      data_set = SparkHiveDataSet(database="test_database", table="test_table",
                                  write_mode="overwrite")
      data_set.save(spark_df)
      reloaded = data_set.load()

      reloaded.take(4)

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `save`(data) | Saves data by delegation to the provided save method.

  `__init__`(database, table, write_mode, table_pk=None)

    Creates a new instance of `SparkHiveDataSet`.

    Parameters

      - database (`str`) – The name of the hive database.

      - table (`str`) – The name of the table within the database.

      - write_mode (`str`) – `insert`, `upsert` or `overwrite` are supported.

      - table_pk (`Optional`[`List`[`str`]]) – If performing an upsert, this identifies the primary key columns used to resolve preexisting data. Is required for `write_mode="upsert"`.

    Raises

      DataSetError – Invalid configuration supplied

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`